@@ -10,13 +10,14 @@ from ruth_tts_transformer.utils.audio import load_voice
 
 
 class TTS:
-    def __init__(self, voice: Text = "gabby_reading"):
+    def __init__(self):
         self.gen = None
+        self.voice = None
         self.preset = "ultra_fast"
-        self.voice = voice
         self.tts = TextToSpeech()
 
-    def generate(self, text):
+    def generate(self, text, voice: Text = "gabby_reading"):
+        self.voice = voice
         voice_samples, conditioning_latents = load_voice(self.voice)
         self.gen, _ = self.tts.tts(text, voice_samples=voice_samples,
                                    conditioning_latents=conditioning_latents,
